;; Generated package description from pg.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "pg" "0.65.0.20260418.140736" "Socket-level interface to the PostgreSQL database" '((emacs "28.1") (peg "1.0.1")) :commit "b3f24200ae8fbd87984d3b3b2909987b309cd738" :authors '(("Eric Marsden" . "eric.marsden@risk-engineering.org")) :maintainer '("Eric Marsden" . "eric.marsden@risk-engineering.org") :keywords '("data" "comm" "database" "postgresql") :url "https://github.com/emarsden/pg-el")
